@@ -394,7 +394,7 @@ END
      ______                  _    ,
        / /              /   ' )  /        /
     --/ /_  __.  ____  /_    /  / __ . . /
-   (_/ / /_(_/|_/ / <_/ <_  (__/_(_)(_/_'   For Trying
+   (_/ / /_(_/|_/ / <_/ <_  (__/_(_)(_/_'   For Using
                              //
 
            _   _      _         _____      _ _    _         _
@@ -407,15 +407,19 @@ END
    Copyright © 2000-2016  Brian M. Kelly  Brian.Kelly@FullAuto.com
 
 END
-      eval {
-         local $SIG{ALRM} = sub { die "alarm\n" }; # \n required
-         alarm 15;
+      if (defined $Net::FullAuto::FA_Core::dashboard) {
+         eval {
+            local $SIG{ALRM} = sub { die "alarm\n" }; # \n required
+            alarm 15;
+            print $thanks;
+            print "   \n   Press Any Key to EXIT ... ";
+            <STDIN>;
+         };alarm(0);
+         print "\n\n\n   Please wait at least a minute for the Default Browser\n",
+               "   to start with your new Hadoop® installation!\n\n\n";
+      } else {
          print $thanks;
-         print "   \n   Press Any Key to EXIT ... ";
-         <STDIN>;
-      };alarm(0);
-      print "\n\n\n   Please wait at least a minute for the Default Browser\n",
-            "   to start with your new Apache™ Hadoop® installation!\n\n\n";
+      }
       &Net::FullAuto::FA_Core::cleanup;
 
    }
