@@ -697,7 +697,7 @@ my $standup_liferay=sub {
      ______                  _    ,
        / /              /   ' )  /        /
     --/ /_  __.  ____  /_    /  / __ . . /
-   (_/ / /_(_/|_/ / <_/ <_  (__/_(_)(_/_'   For Trying
+   (_/ / /_(_/|_/ / <_/ <_  (__/_(_)(_/_'   For Using
                              //
 
            _   _      _         _____      _ _    _         _
@@ -707,18 +707,22 @@ my $standup_liferay=sub {
           |_| \_|\___|\__|     |_|   \__,_|_|_/_/   \_\__,_|\__\___/ ©
 
 
-   Copyright © 2000-2015  Brian M. Kelly  Brian.Kelly@FullAuto.com
+   Copyright © 2000-2016  Brian M. Kelly  Brian.Kelly@FullAuto.com
 
 END
-   eval {
-      local $SIG{ALRM} = sub { die "alarm\n" }; # \n required
-      alarm 15;
+   if (defined $Net::FullAuto::FA_Core::dashboard) {
+      eval {
+         local $SIG{ALRM} = sub { die "alarm\n" }; # \n required
+         alarm 15;
+         print $thanks;
+         print "   \n   Press Any Key to EXIT ... ";
+         <STDIN>;
+      };alarm(0);
+      print "\n\n\n   Please wait at least a minute for the Default Browser\n",
+            "   to start with your new Liferay® installation!\n\n\n";
+   } else {
       print $thanks;
-      print "   \n   Press Any Key to EXIT ... ";
-      <STDIN>;
-   };alarm(0);
-   print "\n\n\n   Please wait at least a minute for the Default Browser\n",
-         "   to start with your new Liferay installation!\n\n\n";
+   }
    &Net::FullAuto::FA_Core::cleanup;
 
 };
